.. currentmodule:: fastdla

=====================================
Pauli products and Pauli product sums
=====================================

.. autosummary::
   :toctree: ../generated
   :recursive:

   PauliProduct
   SparsePauliSum
   SparsePauliSumArray
